@@ -17,12 +17,21 @@ class Executor(ABC):
     Executor for rules.
     """
 
+    @abstractmethod
+    def cache(self) -> Cache | None:
+        raise NotImplementedError()
+
+    @abstractmethod
+    def set_cache(self, cache: Cache | None) -> None:
+        raise NotImplementedError()
+
     @abstractmethod
     def execute(self, rule: ProductionRule, params: Params, engine: RuleEngine) -> Any:
         """
         Execute the specified rule with the specified params.
         """
-        ...
+
+        raise NotImplementedError()
 
     @staticmethod
     def simple(cache: Cache) -> "Executor":
@@ -49,17 +58,24 @@ class SimpleExecutor(Executor):
     def __init__(self, cache: Cache) -> None:
         self._cache = cache
 
+    def cache(self) -> Cache | None:
+        return self._cache
+
+    def set_cache(self, cache: Cache | None) -> None:
+        self._cache = cache or Cache.none()
+
     def execute(self, rule: ProductionRule, params: Params, engine: RuleEngine) -> Any:
         try:
             return self._cache.get(rule, params)
         except KeyError:
             with engine.activate():
                 result = rule.func(params)
-            assert isinstance(
-                result, rule.output_type
-            ), "ProductionRule output (type: %r) does not match ProductionRule output type: %r" % (
-                type(result),
-                rule.output_type,
+            assert isinstance(result, rule.output_type), (
+                "ProductionRule output (type: %r) does not match ProductionRule output type: %r"
+                % (
+                    type(result),
+                    rule.output_type,
+                )
             )
             self._cache.set(rule, params, result)
             return result
@@ -76,16 +92,23 @@ class ThreadedExecutor(Executor):
         self._pending: dict[int, Future[Any]] = {}
         self._executor = ThreadPoolExecutor()
 
+    def cache(self) -> Cache | None:
+        return self._cache
+
+    def set_cache(self, cache: Cache | None) -> None:
+        self._cache = cache or Cache.none()
+
     def _on_result(self, rule: ProductionRule, params: Params, key: int) -> None:
         with self._lock:
             future = self._pending.pop(key)
             assert future.done(), "Future is not done"
             result = future.result()
-            assert isinstance(
-                result, rule.output_type
-            ), "ProductionRule output (type: %r) does not match ProductionRule output type: %r" % (
-                type(result),
-                rule.output_type,
+            assert isinstance(result, rule.output_type), (
+                "ProductionRule output (type: %r) does not match ProductionRule output type: %r"
+                % (
+                    type(result),
+                    rule.output_type,
+                )
             )
             self._cache.set(rule, params, result)
 
@@ -93,7 +116,7 @@ class ThreadedExecutor(Executor):
         try:
             return self._cache.get(rule, params)
         except KeyError:
-            key = hash((rule.id, params))
+            key = params.hasher((rule.id, params))
             with self._lock:
                 try:
                     future = self._pending[key]
