@@ -58,7 +58,7 @@ information.
     Params(42, MyGeneric(value=1))
     """
 
-    InitType: TypeAlias = Sequence[object] | Mapping[type[Any], object] | "Params" | object
+    InitType: TypeAlias = "Sequence[object] | Mapping[type[Any], object] | Params | object"
 
     _params: dict[type[Any], object]
     _hasher: Hasher
@@ -148,12 +148,10 @@ information.
         return bool(self._params)
 
     @overload
-    def get(self, param_type: type[T]) -> T:
-        ...
+    def get(self, param_type: type[T]) -> T: ...
 
     @overload
-    def get(self, param_type: type[T], default: U) -> T | U:
-        ...
+    def get(self, param_type: type[T], default: U) -> T | U: ...
 
     def get(self, param_type: type[T], default: U | object = _Sentinel) -> T | U:
         try:
